Reference Files
===============

The ``extract_2d`` step uses the WAVELENGTHRANGE reference file.
The WAVELENGTHRANGE reference file is only used for NIRCam and NIRISS
Wide-Field Slitless Spectroscopy (WFSS) exposures.

.. include:: ../references_general/wavelengthrange_reffile.inc
